@@ -8,6 +8,7 @@ import base64
 import logging
 import os
 import queue
+import shutil
 import subprocess
 import sys
 import tempfile
@@ -172,6 +173,10 @@ class SystemTrayTests(unittest.TestCase):
         """
         Opens the widget and initialize the webdriver
         """
+        # Install the test widget
+        os.makedirs(os.path.join(GLib.get_user_data_dir(), "plasma", "plasmoids"))
+        shutil.copytree(os.path.join(os.path.dirname(os.path.abspath(__file__)), "systemtraytest", "org.kde.testdbusactivation"), os.path.join(GLib.get_user_data_dir(), "plasma", "plasmoids", "org.kde.testdbusactivation"))
+
         options = AppiumOptions()
         options.set_capability("app", f"plasmawindowed -p org.kde.plasma.nano {WIDGET_ID}")
         options.set_capability("environ", {
@@ -368,6 +373,7 @@ class SystemTrayTests(unittest.TestCase):
         # Scroll right
         self.scroll_center(rect, 15, 0)
 
+    @unittest.skipIf(os.getenv("TEST_WITH_KWIN_WAYLAND", "1") == "0", "inputsynth only works on Wayland")
     def test_2_statusnotifieritem(self) -> None:
         """
         Tests for org.kde.StatusNotifierItem
@@ -378,9 +384,6 @@ class SystemTrayTests(unittest.TestCase):
         5. Activate menu actions
         6. NeedsAttention/Active/Passive status
         """
-        if os.getenv("TEST_WITH_KWIN_WAYLAND", "1") == "0":
-            self.skipTest("inputsynth only works on Wayland")
-
         status_notifier = subprocess.Popen([os.path.join(CMAKE_RUNTIME_OUTPUT_DIRECTORY, "systemtray_statusnotifiertest")], stdout=subprocess.PIPE)
         self.addCleanup(status_notifier.terminate)
         time.sleep(1)  # Wait until the icon appears
@@ -452,13 +455,11 @@ class SystemTrayTests(unittest.TestCase):
         for l in range(0, len(expected_result)):
             self.assertEqual(output[l].decode().strip(), expected_result[l])
 
+    @unittest.skipIf(os.environ.get("TEST_WITH_KWIN_WAYLAND", "1") == "0", "In openbox, the popup is not focused by default, so sending keys will not work.")
     def test_3_bug479466_keyboard_navigation_in_HiddenItemsView(self) -> None:
         """
         Make sure iconContainer in AbstractItem.qml has the default focus so it can receive key presses
         """
-        if os.environ.get("TEST_WITH_KWIN_WAYLAND", "1") == "0":
-            self.skipTest("In openbox, the popup is not focused by default, so sending keys will not work.")
-
         self.driver.find_element(AppiumBy.NAME, "Show hidden icons").click()
         wait = WebDriverWait(self.driver, 10)
         wait.until(EC.presence_of_element_located((AppiumBy.NAME, "Notifications")))
@@ -471,9 +472,29 @@ class SystemTrayTests(unittest.TestCase):
         else:
             actions = ActionChains(self.driver)
             actions.send_keys(Keys.ENTER).perform()
-        wait.until(EC.presence_of_element_located((AppiumBy.NAME, "Do not disturb")))
+        element = wait.until(EC.presence_of_element_located((AppiumBy.NAME, "Do not disturb")))
+
+        self.driver.find_element(AppiumBy.NAME, "Go Back").click()
+        wait.until_not(lambda _: element.is_displayed())
+
+        if os.environ.get("TEST_WITH_KWIN_WAYLAND", "1") == "0":
+            subprocess.check_call(["xdotool", "key", "Escape"])
+        else:
+            ActionChains(self.driver).send_keys(Keys.ESCAPE).perform()
+
+    def test_4_dbus_activated_plasmoid(self) -> None:
+        """
+        Dynamically load a Plasmoid into the systemtray when a specific service becomes available
+        """
+        with subprocess.Popen(["python3", os.path.join(os.path.dirname(os.path.abspath(__file__)), "systemtraytest", "dbusservice.py")], stdout=sys.stderr, stderr=sys.stderr) as process:
+            plasmoid_title = "Do not translate Test only"
+            element = self.driver.find_element(AppiumBy.NAME, plasmoid_title)
+            process.kill()
+        WebDriverWait(self.driver, 10).until_not(lambda _: element.is_displayed())
 
 
 if __name__ == '__main__':
+    assert "USE_CUSTOM_BUS" in os.environ
+    assert "GDK_BACKEND" in os.environ or "TEST_WITH_KWIN_WAYLAND" in os.environ
     logging.getLogger().setLevel(logging.INFO)
     unittest.main()
