@@ -23,6 +23,7 @@
 
 DeviceControl::DeviceControl(QObject *parent)
     : QAbstractListModel(parent)
+    , m_encryptedPredicate(Solid::Predicate(QStringLiteral("StorageVolume"), QStringLiteral("usage"), QLatin1String("Encrypted")))
     , m_types({
           Solid::DeviceInterface::PortableMediaPlayer,
           Solid::DeviceInterface::Camera,
@@ -33,7 +34,6 @@ DeviceControl::DeviceControl(QObject *parent)
           Solid::DeviceInterface::NetworkShare,
           Solid::DeviceInterface::StorageAccess,
       })
-    , m_encryptedPredicate(Solid::Predicate(QStringLiteral("StorageVolume"), QStringLiteral("usage"), QLatin1String("Encrypted")))
     , m_spaceMonitor(SpaceMonitor::instance())
     , m_stateMonitor(DevicesStateMonitor::instance())
     , m_errorMonitor(DeviceErrorMonitor::instance())
@@ -235,7 +235,7 @@ void DeviceControl::onDeviceAdded(const QString &udi)
             it->append(m_devices[position]);
         } else {
             if (m_devices[position].parent().is<Solid::StorageDrive>()) {
-                qCDebug(APPLETS::DEVICENOTIFIER) << "Device Controller: " << "Creating a new parent list";
+                qCDebug(APPLETS::DEVICENOTIFIER) << "Device Controller: Creating a new parent list";
                 m_parentDevices.insert(m_devices[position].parent().udi(), {m_devices[position]});
             } else {
                 qCDebug(APPLETS::DEVICENOTIFIER) << "Device Controller: Parent device is not valid. Don't add one";
