@@ -37,6 +37,11 @@ QString AbstractEntry::name() const
     return QString();
 }
 
+QString AbstractEntry::compactName() const
+{
+    return name();
+}
+
 QString AbstractEntry::group() const
 {
     return QString();
@@ -85,6 +90,16 @@ bool AbstractEntry::run(const QString &actionId, const QVariant &argument)
     return false;
 }
 
+void AbstractEntry::reload()
+{
+    return;
+}
+
+void AbstractEntry::refreshLabels()
+{
+    return;
+}
+
 AbstractGroupEntry::AbstractGroupEntry(AbstractModel *owner)
     : AbstractEntry(owner)
 {
