@@ -6,12 +6,10 @@
 
 #include "kickercompattrianglemousefilter.h"
 
-#include "debug.h"
-
 KickerCompatTriangleMouseFilter::KickerCompatTriangleMouseFilter(QQuickItem *parent)
     : TriangleMouseFilter(parent)
 {
-    qCWarning(KICKER_DEBUG) << "Kicker.TriangleMouseFilter is deprecated and will be removed in Plasma 6. Import TriangleMouseFilter from "
-                               "org.kde.plasma.workspace.trianglemousefilter instead";
     setProperty("blockFirstEnter", true);
 }
+
+#include "moc_kickercompattrianglemousefilter.cpp"
