@@ -21,7 +21,7 @@
 #include <KPropertiesDialog>
 #include <KProtocolManager>
 #include <KSharedConfig>
-#include <KStandardAction>
+#include <KStandardActions>
 #include <KUrlMimeData>
 
 #include <KIO/CopyJob> // for KIO::trash
@@ -162,7 +162,7 @@ void FileMenu::open(int x, int y)
             });
             handler->askUserDelete({m_url}, KIO::AskUserActionInterface::Trash, KIO::AskUserActionInterface::DefaultConfirmation);
         };
-        QAction *moveToTrashAction = KStandardAction::moveToTrash(this, moveToTrashLambda, menu);
+        QAction *moveToTrashAction = KStandardActions::moveToTrash(this, moveToTrashLambda, menu);
         moveToTrashAction->setShortcut({}); // Can't focus notification to press Delete
         menu->addAction(moveToTrashAction);
     }
@@ -182,7 +182,7 @@ void FileMenu::open(int x, int y)
             });
             handler->askUserDelete({m_url}, KIO::AskUserActionInterface::Delete, KIO::AskUserActionInterface::DefaultConfirmation);
         };
-        QAction *deleteAction = KStandardAction::deleteFile(this, deleteLambda, menu);
+        QAction *deleteAction = KStandardActions::deleteFile(this, deleteLambda, menu);
         deleteAction->setShortcut({});
         menu->addAction(deleteAction);
     }
@@ -238,3 +238,5 @@ void FileMenu::open(int x, int y)
     m_visible = true;
     Q_EMIT visibleChanged();
 }
+
+#include "moc_filemenu.cpp"
