@@ -142,14 +142,14 @@ void PlasmaAppletItem::setRunning(int count)
 
 QString PlasmaAppletItem::apiVersion() const
 {
-    return m_info.value(QStringLiteral("X-Plasma-API-Minimum-Version"));
+    return m_info.value(u"X-Plasma-API-Minimum-Version");
 }
 
 bool PlasmaAppletItem::isRecent() const
 {
-    const QFileInfo configInformation(m_info.fileName());
-    QDir dir = configInformation.dir();
-
+    QDir dir = QDir(m_info.fileName());
+    dir.cdUp();
+    const QFileInfo appletFolderInfo(dir.absolutePath());
     // The manifest file is in the folder of its theme,
     // which is in the plasmashell folder, which is in
     // a share folder. We use the latter as a reference
@@ -165,7 +165,7 @@ bool PlasmaAppletItem::isRecent() const
     const QFileInfo shareFolderInformation(dir.absolutePath());
 
     const auto shareFolderBirthTime = shareFolderInformation.birthTime();
-    const auto configBirthTime = configInformation.birthTime();
+    const auto configBirthTime = appletFolderInfo.birthTime();
     const auto oneHourAgo = QDateTime::currentDateTime().addSecs(-3600);
 
     // A widget is considered recent when it was created within the last hour,
@@ -330,22 +330,22 @@ PlasmaAppletItemModel::PlasmaAppletItemModel(QObject *parent)
 QHash<int, QByteArray> PlasmaAppletItemModel::roleNames() const
 {
     QHash<int, QByteArray> newRoleNames = QAbstractItemModel::roleNames();
-    newRoleNames[NameRole] = "name";
-    newRoleNames[PluginNameRole] = "pluginName";
-    newRoleNames[DescriptionRole] = "description";
-    newRoleNames[CategoryRole] = "category";
-    newRoleNames[LicenseRole] = "license";
-    newRoleNames[WebsiteRole] = "website";
-    newRoleNames[VersionRole] = "version";
-    newRoleNames[AuthorRole] = "author";
-    newRoleNames[EmailRole] = "email";
-    newRoleNames[RunningRole] = "running";
-    newRoleNames[LocalRole] = "local";
-    newRoleNames[ScreenshotRole] = "screenshot";
-    newRoleNames[ApiVersionRole] = "apiVersion";
-    newRoleNames[IsSupportedRole] = "isSupported";
-    newRoleNames[UnsupportedMessageRole] = "unsupportedMessage";
-    newRoleNames[RecentRole] = "recent";
+    newRoleNames[NameRole] = QByteArrayLiteral("name");
+    newRoleNames[PluginNameRole] = QByteArrayLiteral("pluginName");
+    newRoleNames[DescriptionRole] = QByteArrayLiteral("description");
+    newRoleNames[CategoryRole] = QByteArrayLiteral("category");
+    newRoleNames[LicenseRole] = QByteArrayLiteral("license");
+    newRoleNames[WebsiteRole] = QByteArrayLiteral("website");
+    newRoleNames[VersionRole] = QByteArrayLiteral("version");
+    newRoleNames[AuthorRole] = QByteArrayLiteral("author");
+    newRoleNames[EmailRole] = QByteArrayLiteral("email");
+    newRoleNames[RunningRole] = QByteArrayLiteral("running");
+    newRoleNames[LocalRole] = QByteArrayLiteral("local");
+    newRoleNames[ScreenshotRole] = QByteArrayLiteral("screenshot");
+    newRoleNames[ApiVersionRole] = QByteArrayLiteral("apiVersion");
+    newRoleNames[IsSupportedRole] = QByteArrayLiteral("isSupported");
+    newRoleNames[UnsupportedMessageRole] = QByteArrayLiteral("unsupportedMessage");
+    newRoleNames[RecentRole] = QByteArrayLiteral("recent");
     return newRoleNames;
 }
 
@@ -354,7 +354,7 @@ void PlasmaAppletItemModel::populateModel()
     clear();
 
     auto filter = [this](const KPluginMetaData &plugin) -> bool {
-        const QStringList provides = plugin.value(QStringLiteral("X-Plasma-Provides"), QStringList());
+        const QStringList provides = plugin.value(u"X-Plasma-Provides", QStringList());
 
         if (!m_provides.isEmpty()) {
             const bool providesFulfilled = std::any_of(m_provides.cbegin(), m_provides.cend(), [&provides](const QString &p) {
@@ -366,7 +366,7 @@ void PlasmaAppletItemModel::populateModel()
             }
         }
 
-        if (!plugin.isValid() || plugin.rawData().value(QStringLiteral("NoDisplay")).toBool() || plugin.category() == QLatin1String("Containments")) {
+        if (!plugin.isValid() || plugin.rawData().value(u"NoDisplay").toBool() || plugin.category() == QLatin1String("Containments")) {
             // we don't want to show the hidden category
             return false;
         }
@@ -407,7 +407,7 @@ void PlasmaAppletItemModel::populateModel()
     // Search all packages that have json metadata but not a correct Plasma/Applet and put them at the end: assume they are plasma5 plasmoids
     packages.append(
         KPackage::PackageLoader::self()->findPackages(QString(), QStringLiteral("plasma/plasmoids"), [&filter](const KPluginMetaData &plugin) -> bool {
-            return plugin.value(QStringLiteral("KPackageStructure")) != QStringLiteral("Plasma/Applet") && filter(plugin);
+            return plugin.value(u"KPackageStructure") != u"Plasma/Applet" && filter(plugin);
         }));
 
     for (const KPluginMetaData &plugin : packages) {
@@ -523,3 +523,5 @@ QString &PlasmaAppletItemModel::Application()
 }
 
 // #include <plasmaappletitemmodel_p.moc>
+
+#include "moc_plasmaappletitemmodel_p.cpp"
