@@ -153,9 +153,9 @@ void WidgetExplorerPrivate::initFilters()
 
         filterModel.addFilter(i18nc("@item:inmenu used in the widget filter. Filter widgets that can be un-installed from the system, which are usually "
                                     "installed by the user to a local place.",
-                                    "Uninstallable"),
+                                    "User-installed"),
                               KCategorizedItemsViewModels::Filter(QStringLiteral("local"), true),
-                              QIcon::fromTheme(QStringLiteral("edit-delete")));
+                              QIcon::fromTheme(QStringLiteral("user-identity-symbolic")));
 
         filterModel.addFilter(i18nc("@item:inmenu used in the widget filter. Filter widgets that can were recently installed.", "Recently installed"),
                               KCategorizedItemsViewModels::Filter(QStringLiteral("recent"), true),
@@ -560,6 +560,11 @@ void WidgetExplorer::uninstall(const QString &pluginName)
     }
 
     // now remove all instances of that applet
+    removeAllInstances(pluginName);
+}
+
+void WidgetExplorer::removeAllInstances(const QString &pluginName)
+{
     if (corona()) {
         const auto &containments = corona()->containments();
 
