@@ -11,6 +11,8 @@
 #include <QStringList>
 #include <QTextStream>
 
+using namespace Qt::StringLiterals;
+
 namespace KFI
 {
 Style::Style(const QDomElement &elem, bool loadFiles)
@@ -38,7 +40,7 @@ Style::Style(const QDomElement &elem, bool loadFiles)
         }
     }
 
-    m_scalable = !elem.hasAttribute(SCALABLE_ATTR) || elem.attribute(SCALABLE_ATTR) != "false";
+    m_scalable = !elem.hasAttribute(SCALABLE_ATTR) || elem.attribute(SCALABLE_ATTR) != u"false";
     m_value = FC::createStyleVal(weight, width, slant);
     m_writingSystems = 0;
 
@@ -83,43 +85,43 @@ QString Style::toXml(bool disabled, const QString &family) const
     }
 
     if (files.count() > 0) {
-        QString str("  <" FONT_TAG " ");
+        QString str(u"  <" + FONT_TAG + u' ');
         int weight, width, slant;
 
         KFI::FC::decomposeStyleVal(m_value, weight, width, slant);
 
         if (!family.isEmpty()) {
-            str += FAMILY_ATTR "=\"" + family + "\" ";
+            str += FAMILY_ATTR + u"=\"" + family + u"\" ";
         }
         if (KFI_NULL_SETTING != weight) {
-            str += WEIGHT_ATTR "=\"" + QString::number(weight) + "\" ";
+            str += WEIGHT_ATTR + u"=\"" + QString::number(weight) + u"\" ";
         }
         if (KFI_NULL_SETTING != width) {
-            str += WIDTH_ATTR "=\"" + QString::number(width) + "\" ";
+            str += WIDTH_ATTR + u"=\"" + QString::number(width) + u"\" ";
         }
         if (KFI_NULL_SETTING != slant) {
-            str += SLANT_ATTR "=\"" + QString::number(slant) + "\" ";
+            str += SLANT_ATTR + u"=\"" + QString::number(slant) + u"\" ";
         }
         if (!m_scalable) {
-            str += SCALABLE_ATTR "=\"false\" ";
+            str += SCALABLE_ATTR + u"=\"false\" ";
         }
 
         QStringList ws(WritingSystems::instance()->getLangs(m_writingSystems));
 
         if (!ws.isEmpty()) {
-            str += LANGS_ATTR "=\"" + ws.join(LANG_SEP) + "\" ";
+            str += LANGS_ATTR + u"=\"" + ws.join(LANG_SEP) + u"\" ";
         }
 
         if (1 == files.count()) {
-            str += (*files.begin()) + "/>";
+            str += (*files.begin()) + u"/>";
         } else {
             QStringList::ConstIterator it(files.begin()), end(files.end());
 
-            str += ">\n";
+            str += QStringView(u">\n");
             for (; it != end; ++it) {
-                str += "   <" FILE_TAG " " + (*it) + "/>\n";
+                str += u"   <" + FILE_TAG + u' ' + (*it) + u"/>\n";
             }
-            str += "  </" FONT_TAG ">";
+            str += u"  </" + FONT_TAG + u">";
         }
 
         return str;
