@@ -22,15 +22,11 @@ struct DBusMenuItem {
     QVariantMap properties;
 };
 
-Q_DECLARE_METATYPE(DBusMenuItem)
-
 QDBusArgument &operator<<(QDBusArgument &argument, const DBusMenuItem &item);
 const QDBusArgument &operator>>(const QDBusArgument &argument, DBusMenuItem &item);
 
 typedef QList<DBusMenuItem> DBusMenuItemList;
 
-Q_DECLARE_METATYPE(DBusMenuItemList)
-
 //// DBusMenuItemKeys
 /**
  * Represents a list of keys for a menu item
@@ -40,15 +36,11 @@ struct DBusMenuItemKeys {
     QStringList properties;
 };
 
-Q_DECLARE_METATYPE(DBusMenuItemKeys)
-
 QDBusArgument &operator<<(QDBusArgument &argument, const DBusMenuItemKeys &);
 const QDBusArgument &operator>>(const QDBusArgument &argument, DBusMenuItemKeys &);
 
 typedef QList<DBusMenuItemKeys> DBusMenuItemKeysList;
 
-Q_DECLARE_METATYPE(DBusMenuItemKeysList)
-
 //// DBusMenuLayoutItem
 /**
  * Represents an item with its children. GetLayout() returns a
@@ -61,15 +53,11 @@ struct DBusMenuLayoutItem {
     QList<DBusMenuLayoutItem> children;
 };
 
-Q_DECLARE_METATYPE(DBusMenuLayoutItem)
-
 QDBusArgument &operator<<(QDBusArgument &argument, const DBusMenuLayoutItem &);
 const QDBusArgument &operator>>(const QDBusArgument &argument, DBusMenuLayoutItem &);
 
 typedef QList<DBusMenuLayoutItem> DBusMenuLayoutItemList;
 
-Q_DECLARE_METATYPE(DBusMenuLayoutItemList)
-
 //// DBusMenuShortcut
 
 class DBusMenuShortcut;
