@@ -58,6 +58,20 @@ void NotificationFilterProxyModel::setShowDismissed(bool show)
     }
 }
 
+bool NotificationFilterProxyModel::showAddedDuringInhibition() const
+{
+    return m_showDismissed;
+}
+
+void NotificationFilterProxyModel::setShowAddedDuringInhibition(bool show)
+{
+    if (m_showAddedDuringInhibition != show) {
+        m_showAddedDuringInhibition = show;
+        invalidateFilter();
+        Q_EMIT showAddedDuringInhibitionChanged();
+    }
+}
+
 QStringList NotificationFilterProxyModel::blacklistedDesktopEntries() const
 {
     return m_blacklistedDesktopEntries;
@@ -177,5 +191,11 @@ bool NotificationFilterProxyModel::filterAcceptsRow(int source_row, const QModel
         }
     }
 
+    if (!m_showAddedDuringInhibition && sourceIdx.data(Notifications::WasAddedDuringInhibitionRole).toBool()) {
+        return false;
+    }
+
     return true;
 }
+
+#include "moc_notificationfilterproxymodel_p.cpp"
