@@ -14,6 +14,7 @@
 #include "debug.h"
 
 #include <KStartupInfo>
+#include <KWaylandExtras>
 #include <KWindowSystem>
 #include <QDebug>
 
@@ -23,15 +24,15 @@ Server::Server(QObject *parent)
     : QObject(parent)
     , d(new ServerPrivate(this))
 {
-    connect(d.data(), &ServerPrivate::validChanged, this, &Server::validChanged);
-    connect(d.data(), &ServerPrivate::inhibitedChanged, this, [this] {
+    connect(d.get(), &ServerPrivate::validChanged, this, &Server::validChanged);
+    connect(d.get(), &ServerPrivate::inhibitedChanged, this, [this] {
         Q_EMIT inhibitedChanged(inhibited());
     });
-    connect(d.data(), &ServerPrivate::externalInhibitedChanged, this, [this] {
+    connect(d.get(), &ServerPrivate::externalInhibitedChanged, this, [this] {
         Q_EMIT inhibitedByApplicationChanged(inhibitedByApplication());
     });
-    connect(d.data(), &ServerPrivate::externalInhibitionsChanged, this, &Server::inhibitionApplicationsChanged);
-    connect(d.data(), &ServerPrivate::serviceOwnershipLost, this, &Server::serviceOwnershipLost);
+    connect(d.get(), &ServerPrivate::externalInhibitionsChanged, this, &Server::inhibitionApplicationsChanged);
+    connect(d.get(), &ServerPrivate::serviceOwnershipLost, this, &Server::serviceOwnershipLost);
 }
 
 Server::~Server() = default;
@@ -42,6 +43,12 @@ Server &Server::self()
     return s_self;
 }
 
+Server *Server::create(QQmlEngine *, QJSEngine *)
+{
+    QQmlEngine::setObjectOwnership(&Server::self(), QQmlEngine::CppOwnership);
+    return &Server::self();
+}
+
 bool Server::init()
 {
     return d->init();
@@ -70,10 +77,10 @@ void Server::invokeAction(uint notificationId,
                           QWindow *window)
 {
     if (KWindowSystem::isPlatformWayland()) {
-        const quint32 launchedSerial = KWindowSystem::lastInputSerial(window);
-        auto conn = QSharedPointer<QMetaObject::Connection>::create();
-        *conn = connect(KWindowSystem::self(),
-                        &KWindowSystem::xdgActivationTokenArrived,
+        const quint32 launchedSerial = KWaylandExtras::lastInputSerial(window);
+        auto conn = std::make_shared<QMetaObject::Connection>();
+        *conn = connect(KWaylandExtras::self(),
+                        &KWaylandExtras::xdgActivationTokenArrived,
                         this,
                         [this, actionName, notificationId, launchedSerial, conn, behavior](quint32 serial, const QString &token) {
                             if (serial == launchedSerial) {
@@ -86,7 +93,7 @@ void Server::invokeAction(uint notificationId,
                                 }
                             }
                         });
-        KWindowSystem::requestXdgActivationToken(window, launchedSerial, xdgActivationAppId);
+        KWaylandExtras::requestXdgActivationToken(window, launchedSerial, xdgActivationAppId);
     } else {
         KStartupInfoId startupId;
         startupId.initId();
