@@ -10,11 +10,16 @@
 
 #include "notificationmanager_export.h"
 
+#include <qqmlregistration.h>
+
 namespace NotificationManager
 {
+// WARNING: this is unstable API and does not provide any API or ABI gurantee for future Plasma releases and can be removed without any further notice
 class NOTIFICATIONMANAGER_EXPORT WatchedNotificationsModel : public AbstractNotificationsModel
 {
     Q_OBJECT
+    QML_ELEMENT
+
     Q_PROPERTY(bool valid READ valid NOTIFY validChanged)
 
 public:
