@@ -1,25 +1,10 @@
-/********************************************************************
-Copyright 2016  Eike Hein <hein.org>
+/*
+    SPDX-FileCopyrightText: 2016 Eike Hein <hein@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
-
-#ifndef ABSTRACTTASKSMODELIFACE_H
-#define ABSTRACTTASKSMODELIFACE_H
+#pragma once
 
 #include <QObject>
 
@@ -27,7 +12,6 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 
 namespace TaskManager
 {
-
 /**
  * @short Pure virtual method interface for tasks model implementations.
  *
@@ -41,7 +25,9 @@ namespace TaskManager
 class TASKMANAGER_EXPORT AbstractTasksModelIface
 {
 public:
-    virtual ~AbstractTasksModelIface() {}
+    virtual ~AbstractTasksModelIface()
+    {
+    }
 
     /**
      * Request activation of the task at the given index. Implementing classes
@@ -210,10 +196,7 @@ public:
      * regard to extracting information from this, and should take care to
      * reject invalid objects.
      **/
-    virtual void requestPublishDelegateGeometry(const QModelIndex &index, const QRect &geometry,
-        QObject *delegate = nullptr) = 0;
+    virtual void requestPublishDelegateGeometry(const QModelIndex &index, const QRect &geometry, QObject *delegate = nullptr) = 0;
 };
 
 }
-
-#endif
