@@ -8,6 +8,8 @@
 
 #include <QAbstractProxyModel>
 
+#include <memory>
+
 #include "abstracttasksmodeliface.h"
 #include "tasksmodel.h"
 
@@ -378,7 +380,7 @@ Q_SIGNALS:
 
 private:
     class Private;
-    QScopedPointer<Private> d;
+    std::unique_ptr<Private> d;
 
     Q_PRIVATE_SLOT(d, void sourceRowsAboutToBeInserted(const QModelIndex &parent, int first, int last))
     Q_PRIVATE_SLOT(d, void sourceRowsInserted(const QModelIndex &parent, int start, int end))
@@ -386,7 +388,7 @@ private:
     Q_PRIVATE_SLOT(d, void sourceRowsRemoved(const QModelIndex &parent, int start, int end))
     Q_PRIVATE_SLOT(d, void sourceModelAboutToBeReset())
     Q_PRIVATE_SLOT(d, void sourceModelReset())
-    Q_PRIVATE_SLOT(d, void sourceDataChanged(QModelIndex, QModelIndex, QVector<int>))
+    Q_PRIVATE_SLOT(d, void sourceDataChanged(QModelIndex, QModelIndex, QList<int>))
 };
 
 }
