@@ -127,7 +127,7 @@ AppData appDataFromUrl(const QUrl &url, const QIcon &fallbackIcon)
                 }
             }
 
-            if (data.id.endsWith(".desktop")) {
+            if (data.id.endsWith(u".desktop")) {
                 data.id = data.id.left(data.id.length() - 8);
             }
         } else {
@@ -229,14 +229,14 @@ QUrl windowUrlFromMetadata(const QString &appId, quint32 pid, const KSharedConfi
         }
 
         // Try to match using xWindowsWMClassName also.
-        if (!xWindowsWMClassName.isEmpty() && matchCommandLineFirst.contains("::" + xWindowsWMClassName)) {
+        if (!xWindowsWMClassName.isEmpty() && matchCommandLineFirst.contains(u"::" + xWindowsWMClassName)) {
             triedPid = true;
             services = servicesFromPid(pid, rulesConfig);
         }
 
         if (!appId.isEmpty()) {
             // Evaluate any mapping rules that map to a specific .desktop file.
-            QString mapped(grp.readEntry(appId + "::" + xWindowsWMClassName, QString()));
+            QString mapped(grp.readEntry(appId + u"::" + xWindowsWMClassName, QString()));
 
             if (mapped.endsWith(QLatin1String(".desktop"))) {
                 url = QUrl(mapped);
@@ -434,7 +434,7 @@ QUrl windowUrlFromMetadata(const QString &appId, quint32 pid, const KSharedConfi
         QMutableListIterator<KService::Ptr> it(matchingServices);
         while (it.hasNext()) {
             auto service = it.next();
-            if (!service->desktopEntryName().endsWith("." + appId)) {
+            if (!service->desktopEntryName().endsWith(u'.' + appId)) {
                 it.remove();
             }
         }
@@ -453,7 +453,7 @@ QUrl windowUrlFromMetadata(const QString &appId, quint32 pid, const KSharedConfi
         // applications: URLs are used to refer to applications by their KService::menuId
         // (i.e. .desktop file name) rather than the absolute path to a .desktop file.
         if (!menuId.isEmpty()) {
-            url.setUrl(QStringLiteral("applications:") + menuId);
+            url.setUrl(QString(u"applications:" + menuId));
             return url;
         }
 
@@ -542,7 +542,7 @@ KService::List servicesFromCmdLine(const QString &_cmdLine, const QString &proce
         return services;
     }
 
-    const int firstSpace = cmdLine.indexOf(' ');
+    const int firstSpace = cmdLine.indexOf(u' ');
     int slash = 0;
 
     services = KApplicationTrader::query([&cmdLine](const KService::Ptr &service) {
@@ -551,7 +551,7 @@ KService::List servicesFromCmdLine(const QString &_cmdLine, const QString &proce
 
     if (services.isEmpty()) {
         // Could not find with complete command line, so strip out the path part ...
-        slash = cmdLine.lastIndexOf('/', firstSpace);
+        slash = cmdLine.lastIndexOf(u'/', firstSpace);
 
         if (slash > 0) {
             const QStringView midCmd = QStringView(cmdLine).mid(slash + 1);
@@ -570,7 +570,7 @@ KService::List servicesFromCmdLine(const QString &_cmdLine, const QString &proce
         });
 
         if (services.isEmpty()) {
-            slash = cmdLine.lastIndexOf('/');
+            slash = cmdLine.lastIndexOf(u'/');
 
             if (slash > 0) {
                 const QStringView midCmd = QStringView(cmdLine).mid(slash + 1);
@@ -768,8 +768,7 @@ void runApp(const AppData &appData, const QList<QUrl> &urls)
             job->setUrls(urls);
             job->start();
 
-            KActivities::ResourceInstance::notifyAccessed(QUrl(QStringLiteral("applications:") + service->storageId()),
-                                                          QStringLiteral("org.kde.libtaskmanager"));
+            KActivities::ResourceInstance::notifyAccessed(QUrl(QString(u"applications:" + service->storageId())), QStringLiteral("org.kde.libtaskmanager"));
         } else {
             auto *job = new KIO::OpenUrlJob(appData.url);
             job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoErrorHandlingEnabled));
@@ -777,7 +776,7 @@ void runApp(const AppData &appData, const QList<QUrl> &urls)
             job->start();
 
             if (!appData.id.isEmpty()) {
-                KActivities::ResourceInstance::notifyAccessed(QUrl(QStringLiteral("applications:") + appData.id), QStringLiteral("org.kde.libtaskmanager"));
+                KActivities::ResourceInstance::notifyAccessed(QUrl(QString(u"applications:" + appData.id)), QStringLiteral("org.kde.libtaskmanager"));
             }
         }
     }
@@ -816,7 +815,7 @@ bool canLauchNewInstance(const AppData &appData)
         // Hide our own action if there's already a "New Window" action
         const auto actions = service->actions();
         for (const KServiceAction &action : actions) {
-            if (action.name().startsWith("new", Qt::CaseInsensitive) && action.name().endsWith("window", Qt::CaseInsensitive)) {
+            if (action.name().startsWith(u"new", Qt::CaseInsensitive) && action.name().endsWith(u"window", Qt::CaseInsensitive)) {
                 return false;
             }
 
