@@ -36,7 +36,7 @@ public:
     QUrl launcherUrl(const KStartupInfoData &data);
 
 private:
-    XStartupTasksModel *q;
+    XStartupTasksModel *const q;
 };
 
 XStartupTasksModel::Private::Private(XStartupTasksModel *q)
@@ -270,3 +270,5 @@ int XStartupTasksModel::rowCount(const QModelIndex &parent) const
 }
 
 } // namespace TaskManager
+
+#include "moc_xstartuptasksmodel.cpp"
