@@ -103,7 +103,7 @@ public:
     bool demandsAttention(WId window);
 
 private:
-    XWindowTasksModel *q;
+    XWindowTasksModel *const q;
 };
 
 XWindowTasksModel::Private::Private(XWindowTasksModel *q)
@@ -1156,3 +1156,5 @@ QList<WId> XWindowTasksModel::winIdsFromMimeData(const QMimeData *mimeData, bool
 }
 
 }
+
+#include "moc_xwindowtasksmodel.cpp"
