@@ -88,11 +88,9 @@ void ScreenPoolTest::testScreenInsertion()
         data.physicalSize = data.mode.physicalSizeForDpi(96);
         // NOTE: assumes that when a screen is added it will already have the final geometry
         add<Output>(data);
-        outputOrder()->setList({"WL-1", "WL-2"});
+        outputOrder()->setList({u"WL-1"_s, u"WL-2"_s});
     });
 
-    addedSpy.wait();
-
     orderChangeSpy.wait();
 
     QCOMPARE(orderChangeSpy.size(), 1);
@@ -121,10 +119,9 @@ void ScreenPoolTest::testRedundantScreenInsertion()
         data.physicalSize = data.mode.physicalSizeForDpi(96);
         // NOTE: assumes that when a screen is added it will already have the final geometry
         add<Output>(data);
-        outputOrder()->setList({"WL-1", "WL-2", "WL-3"});
+        outputOrder()->setList({u"WL-1"_s, u"WL-2"_s, u"WL-3"_s});
     });
 
-    addedFromAppSpy.wait();
     orderChangeSpy.wait(250);
     // only addedFromAppSpy will have registered something, nothing in orderChangeSpy,
     // on ScreenPool API POV is like this new screen doesn't exist, because is redundant to WL-2
@@ -151,7 +148,7 @@ void ScreenPoolTest::testMoveOutOfRedundant()
         out->m_data.mode.resolution = {1280, 2048};
         xdgOut->sendLogicalSize(QSize(1280, 2048));
         out->sendDone();
-        outputOrder()->setList({"WL-1", "WL-2", "WL-3"});
+        outputOrder()->setList({u"WL-1"_s, u"WL-2"_s, u"WL-3"_s});
     });
 
     orderChangeSpy.wait();
@@ -174,7 +171,7 @@ void ScreenPoolTest::testMoveInRedundant()
         out->m_data.mode.resolution = {1280, 720};
         xdgOut->sendLogicalSize(QSize(1280, 720));
         out->sendDone();
-        outputOrder()->setList({"WL-1", "WL-2", "WL-3"});
+        outputOrder()->setList({u"WL-1"_s, u"WL-2"_s, u"WL-3"_s});
     });
 
     removedSpy.wait();
@@ -201,7 +198,7 @@ void ScreenPoolTest::testOrderSwap()
     // Set a primary screen
     // TODO: "WL-2", "WL-1", "WL-3" when tests are self contained
     exec([this] {
-        outputOrder()->setList({"WL-2", "WL-1", "WL-3"});
+        outputOrder()->setList({u"WL-2"_s, u"WL-1"_s, u"WL-3"_s});
     });
 
     orderChangeSpy.wait();
@@ -230,7 +227,7 @@ void ScreenPoolTest::testPrimarySwapToRedundant()
 
     // Set a primary screen
     exec([this] {
-        outputOrder()->setList({"WL-3", "WL-2", "WL-1"});
+        outputOrder()->setList({u"WL-3"_s, u"WL-2"_s, u"WL-1"_s});
     });
 
     orderChangeSpy.wait(250);
@@ -248,7 +245,7 @@ void ScreenPoolTest::testMoveRedundantToMakePrimary()
         out->m_data.mode.resolution = {1280, 2048};
         xdgOut->sendLogicalSize(QSize(1280, 2048));
         out->sendDone();
-        outputOrder()->setList({"WL-3", "WL-2", "WL-1"});
+        outputOrder()->setList({u"WL-3"_s, u"WL-2"_s, u"WL-1"_s});
     });
 
     QTRY_COMPARE(orderChangeSpy.size(), 1);
@@ -286,7 +283,7 @@ void ScreenPoolTest::testMoveInRedundantToLosePrimary()
         xdgOut->sendLogicalSize(QSize(1280, 720));
         out->m_data.mode.resolution = {1280, 720};
         out->sendDone();
-        outputOrder()->setList({"WL-3", "WL-2", "WL-1"});
+        outputOrder()->setList({u"WL-3"_s, u"WL-2"_s, u"WL-1"_s});
     });
 
     QTRY_COMPARE(orderChangeSpy.size(), 1);
@@ -322,7 +319,7 @@ void ScreenPoolTest::testSecondScreenRemoval()
     // Remove an output
     exec([this] {
         remove(output(1));
-        outputOrder()->setList({"WL-3", "WL-1"});
+        outputOrder()->setList({u"WL-3"_s, u"WL-1"_s});
     });
 
     // Removing the primary screen, will change a primaryChange signal beforehand
@@ -344,7 +341,7 @@ void ScreenPoolTest::testThirdScreenRemoval()
     // Remove an output
     exec([this] {
         remove(output(1));
-        outputOrder()->setList({"WL-1"});
+        outputOrder()->setList({u"WL-1"_s});
     });
 
     // NOTE: we can neither access the data of removedSpy nor oldPrimary because at this point will be dangling
@@ -397,7 +394,7 @@ void ScreenPoolTest::testFakeToRealScreen()
         auto *out = add<Output>(data);
         auto *xdgOut = xdgOutput(out);
         xdgOut->m_name = QStringLiteral("WL-1");
-        outputOrder()->setList({"WL-1"});
+        outputOrder()->setList({u"WL-1"_s});
     });
 
     orderChangeSpy.wait();
@@ -444,7 +441,7 @@ void ScreenPoolTest::testFakeOutputInitially()
         auto *out = add<Output>(data);
         auto *xdgOut = xdgOutput(out);
         xdgOut->m_name = QStringLiteral("WL-1");
-        outputOrder()->setList({QStringLiteral("WL-1")});
+        outputOrder()->setList({u"WL-1"_s});
     });
 
     orderChangeSpy.wait();
