@@ -9,6 +9,7 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 #include <KPackage/Package>
+
 #include <PlasmaActivities/Consumer>
 #include <PlasmaActivities/Info>
 
@@ -26,8 +27,8 @@ using namespace Qt::StringLiterals;
 ScreenPoolModel::ScreenPoolModel(ShellCorona *corona, QObject *parent)
     : QAbstractListModel(parent)
     , m_corona(corona)
+    , m_reloadTimer(new QTimer(this))
 {
-    m_reloadTimer = new QTimer(this);
     m_reloadTimer->setSingleShot(true);
     m_reloadTimer->setInterval(200ms);
 
@@ -152,7 +153,7 @@ void ScreenPoolModel::remove(int screenId)
     auto conts = m_corona->containmentsForScreen(screenId);
     for (auto *cont : std::as_const(conts)) {
         // Don't call destroy directly, so we can have the undo action notification
-        auto *destroyAction = cont->internalAction("remove");
+        auto *destroyAction = cont->internalAction(u"remove"_s);
         if (destroyAction) {
             destroyAction->trigger();
         }
@@ -165,10 +166,10 @@ ShellContainmentModel::ShellContainmentModel(ShellCorona *corona, int screenId,
     : QAbstractListModel(parent)
     , m_screenId(screenId)
     , m_corona(corona)
+    , m_reloadTimer(new QTimer(this))
     , m_screenPoolModel(parent)
     , m_activityConsumer(new KActivities::Consumer(this))
 {
-    m_reloadTimer = new QTimer(this);
     m_reloadTimer->setSingleShot(true);
     m_reloadTimer->setInterval(200ms);
 
@@ -184,7 +185,7 @@ ShellContainmentModel::ShellContainmentModel(ShellCorona *corona, int screenId,
         for (auto &d : m_containments) {
             if (d.containment == containment) {
                 d.image = path;
-                emit dataChanged(index(i, 0), index(i, 0));
+                Q_EMIT dataChanged(index(i, 0), index(i, 0));
                 break;
             }
             ++i;
@@ -276,7 +277,7 @@ void ShellContainmentModel::remove(int contId)
     if (cont) {
         disconnect(cont, nullptr, this, nullptr);
         // Don't call destroy directly, so we can have the undo action notification
-        auto *destroyAction = cont->internalAction("remove");
+        auto *destroyAction = cont->internalAction(u"remove"_s);
         if (destroyAction) {
             destroyAction->trigger();
         }
@@ -403,7 +404,7 @@ QString ShellContainmentModel::plasmaLocationToString(Plasma::Types::Location lo
     case Plasma::Types::RightEdge:
         return u"right"_s;
     default:
-        return QString("unknown");
+        return QStringLiteral("unknown");
     }
 }
 
@@ -479,3 +480,5 @@ void ShellContainmentConfig::init()
         });
     }
 }
+
+#include "moc_shellcontainmentconfig.cpp"
