@@ -39,7 +39,7 @@ public Q_SLOTS:
 private:
     void autoStart(int phase);
 
-    QVector<QProcess *> m_processes;
+    QList<QProcess *> m_processes;
     std::unique_ptr<QEventLoopLocker> m_lock;
     static Startup *s_self;
 };
@@ -60,14 +60,6 @@ public:
     void start() override;
 };
 
-class KDEDInitJob : public KJob
-{
-    Q_OBJECT
-public:
-    KDEDInitJob();
-    void start() override;
-};
-
 class AutoStartAppsJob : public KJob
 {
     Q_OBJECT
