@@ -176,11 +176,11 @@ void PackageFinder::findPreferredImageInPackage(KPackage::Package &package, cons
     const QString preferredDark = findBestMatch(QByteArrayLiteral("images_dark"));
 
     package.removeDefinition("preferred");
-    package.addFileDefinition("preferred", QStringLiteral("images/") + preferred);
+    package.addFileDefinition("preferred", QStringLiteral("images/%1").arg(preferred));
 
     if (!preferredDark.isEmpty()) {
         package.removeDefinition("preferredDark");
-        package.addFileDefinition("preferredDark", QStringLiteral("images_dark%1").arg(QDir::separator()) + preferredDark);
+        package.addFileDefinition("preferredDark", QStringLiteral("images_dark/%1").arg(preferredDark));
     }
 }
 
